# Building the extra print profiles requires colprof, +4Gb of RAM and
# quite a lot of time. Don't enable this for test builds.
%define build_print_profiles	1

%define _icccolordir    %{_datadir}/color/icc

%define major		2
%define gir_major	1.0
%define libname		%mklibname %{name} %{major}
%define devname		%mklibname -d %{name}
%define girname		%mklibname %{name}-gir %{gir_major}

Summary:	Color daemon
Group:		Graphical desktop/GNOME
Name:		colord
Version:	1.3.4
Release:	%mkrel 1
License:	GPLv2+ and LGPLv2+
URL:		http://www.freedesktop.org/software/colord/
Source0:	http://www.freedesktop.org/software/colord/releases/%{name}-%{version}.tar.xz
BuildRequires:	pkgconfig(bash-completion) >= 2.0
BuildRequires:	pkgconfig(glib-2.0) >= 2.28.0
BuildRequires:	pkgconfig(gobject-2.0)
BuildRequires:	pkgconfig(gthread-2.0)
BuildRequires:	pkgconfig(gio-2.0) >= 2.25.9
BuildRequires:	pkgconfig(gio-unix-2.0)
BuildRequires:	pkgconfig(gmodule-2.0)
BuildRequires:	pkgconfig(lcms2)
BuildRequires:	pkgconfig(sqlite3)
BuildRequires:	pkgconfig(gudev-1.0)
BuildRequires:	pkgconfig(gusb)
BuildRequires:	pkgconfig(libusb-1.0) >= 1.0.0
BuildRequires:	pkgconfig(polkit-gobject-1) >= 0.103
BuildRequires:	sane-devel
BuildRequires:	pkgconfig(dbus-1)
BuildRequires:	intltool >= 0.35.0
BuildRequires:	docbook-utils
BuildRequires:	gobject-introspection-devel >= 0.9.8
BuildRequires:	vala-tools
BuildRequires:	locales

%if 0%{?build_print_profiles}
BuildRequires: argyllcms
%endif

Requires(pre):		rpm-helper >= %{rpmhelper_required_version}
Requires(post):		rpm-helper >= %{rpmhelper_required_version}
Requires(preun):	rpm-helper >= %{rpmhelper_required_version}
Requires(postun):	rpm-helper >= %{rpmhelper_required_version}
Obsoletes:		shared-color-profiles < 0.1.5-3
Provides:		shared-color-profiles

%description
colord is a low level system activated daemon that maps color devices
to color profiles in the system context.

%package extra-profiles
Summary:	More color profiles for color management that are less commonly used
Requires:	%{name} = %{version}-%{release}
BuildArch:	noarch

# obsolete separate profiles package
Obsoletes:	shared-color-profiles-extra < 0.1.5-3
Provides:	shared-color-profiles-extra

%description extra-profiles
More color profiles for color management that are less commonly used.
This may be useful for CMYK soft-proofing or for extra device support.

%package -n %{libname}
Summary:	Color daemon run-time libraries
Group:		System/Libraries

%description -n %{libname}
colord is a low level system activated daemon that maps color devices
to color profiles in the system context.

This package contains the run-time libraries for %{name}.

%package -n %{devname}
Summary:	Development files and headers for %{name}
Requires:	%{libname} = %{version}-%{release}
Requires:	%{girname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}

%description -n %{devname}
colord is a low level system activated daemon that maps color devices
to color profiles in the system context.

This package contains the development files and headers for %{name}.

%package -n %{girname}
Summary:	GObject Introspection interface description for %{name}
Group:		System/Libraries
Requires:	%{libname} = %{version}-%{release}

%description -n %{girname}
GObject Introspection interface description for %{name}.

%prep
%setup -q
%autopatch -p1

%build
# Set ~2 GiB limit so that colprof is forced to work in chunks when
# generating the print profile rather than trying to allocate a 3.1 GiB
# chunk of RAM to put the entire B-to-A tables in.
ulimit -Sv 2000000
%configure2_5x \
	--enable-introspection=yes \
	--enable-sane \
	--enable-vala \
%if 0%{?build_print_profiles}
        --enable-print-profiles \
%else
        --disable-print-profiles \
%endif
        --disable-static \
        --disable-rpath \
        --disable-examples \
	--disable-silent-rules \
	--disable-schemas-compile \
	--with-systemdsystemunitdir=%{_unitdir} \
	--with-udevrulesdir=%{_udevrulesdir} \
	--with-daemon-user=colord
LC_ALL=UTF-8 %make

%install
%makeinstall_std

# Remove libtool archives.
find %{buildroot} -name '*.la' -delete

# databases
touch %{buildroot}%{_localstatedir}/lib/colord/mapping.db
touch %{buildroot}%{_localstatedir}/lib/colord/storage.db

%find_lang %{name}

%pre
%_pre_useradd %{name} %{_localstatedir}/lib/colord %{_sbindir}/nologin

%post
if [ -f %{_localstatedir}/lib/colord/mapping.db ]; then
        if [ ! $(stat -c %U %{_localstatedir}/lib/colord/mapping.db) == "colord" ];then
                chown colord: %{_localstatedir}/lib/colord/*.db
       	fi
fi

%_post_service %{name}

%preun
%_preun_service %{name}

%postun
%_postun_userdel %{name}

%files -f %{name}.lang
%doc README.md AUTHORS NEWS MAINTAINERS
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/org.freedesktop.ColorManager.conf
%{_datadir}/dbus-1/interfaces/org.freedesktop.ColorHelper.xml
%{_datadir}/dbus-1/services/org.freedesktop.ColorHelper.service
%{_datadir}/bash-completion/completions/colormgr
%{_bindir}/cd-create-profile
%{_bindir}/cd-fix-profile
%{_bindir}/cd-iccdump
%{_bindir}/colormgr
%{_bindir}/cd-it8
%{_libexecdir}/colord
%{_libdir}/colord-sensors
%{_libexecdir}/colord-sane
%{_libexecdir}/colord-session
%{_unitdir}/colord.service
%{_udevrulesdir}/*.rules
%{_tmpfilesdir}/colord.conf
%{_datadir}/%{name}
%{_datadir}/dbus-1/interfaces/org.freedesktop.ColorManager*.xml
%{_datadir}/dbus-1/system-services/org.freedesktop.ColorManager.service
%{_userunitdir}/colord-session.service
%{_datadir}/polkit-1/actions/org.freedesktop.color.policy
%attr(755,colord,colord) %dir %{_localstatedir}/lib/colord
%attr(-,colord,colord) %ghost %{_localstatedir}/lib/colord/*.db
%{_mandir}/man1/cd-create-profile.1.*
%{_mandir}/man1/cd-fix-profile.1.*
%{_mandir}/man1/colormgr.1.*
%{_mandir}/man1/cd-it8.1.*
%{_datadir}/glib-2.0/schemas/org.freedesktop.ColorHelper.gschema.xml
%{_libdir}/%{name}-plugins/libcd_plugin_*.so

# common colorspaces
%dir %{_icccolordir}/colord
%{_icccolordir}/colord/AdobeRGB1998.icc
%{_icccolordir}/colord/ProPhotoRGB.icc
%{_icccolordir}/colord/SMPTE-C-RGB.icc
%{_icccolordir}/colord/sRGB.icc

# so we can display at least something in the default dropdown
%if 0%{?build_print_profiles}
%{_icccolordir}/colord/FOGRA39L_coated.icc
%endif

# monitor test profiles
%{_icccolordir}/colord/Bluish.icc

# named color profiles
%{_icccolordir}/colord/x11-colors.icc

%files extra-profiles
%if 0%{?build_print_profiles}
%{_icccolordir}/colord/FOGRA27L_coated.icc
%{_icccolordir}/colord/FOGRA28L_webcoated.icc
%{_icccolordir}/colord/FOGRA29L_uncoated.icc
%{_icccolordir}/colord/FOGRA30L_uncoated_yellowish.icc
%{_icccolordir}/colord/FOGRA40L_SC_paper.icc
%{_icccolordir}/colord/FOGRA45L_lwc.icc
%{_icccolordir}/colord/FOGRA47L_uncoated.icc
%{_icccolordir}/colord/GRACoL*.icc
%{_icccolordir}/colord/IFRA26S_2004_newsprint.icc
%{_icccolordir}/colord/SNAP*.icc
%{_icccolordir}/colord/SWOP*.icc
%endif

# other colorspaces not often used
%{_icccolordir}/colord/AppleRGB.icc
%{_icccolordir}/colord/BestRGB.icc
%{_icccolordir}/colord/BetaRGB.icc
%{_icccolordir}/colord/BruceRGB.icc
%{_icccolordir}/colord/CIE-RGB.icc
%{_icccolordir}/colord/ColorMatchRGB.icc
%{_icccolordir}/colord/DonRGB4.icc
%{_icccolordir}/colord/ECI-RGBv1.icc
%{_icccolordir}/colord/ECI-RGBv2.icc
%{_icccolordir}/colord/EktaSpacePS5.icc
%{_icccolordir}/colord/Gamma*.icc
%{_icccolordir}/colord/NTSC-RGB.icc
%{_icccolordir}/colord/PAL-RGB.icc
%{_icccolordir}/colord/SwappedRedAndGreen.icc
%{_icccolordir}/colord/WideGamutRGB.icc

# other named color profiles not generally useful
%{_icccolordir}/colord/Crayons.icc

%files -n %{libname}
%{_libdir}/lib%{name}.so.%{major}{,.*}
%{_libdir}/lib%{name}private.so.%{major}{,.*}
%{_libdir}/libcolorhug.so.%{major}{,.*}

%files -n %{girname}
%{_libdir}/girepository-1.0/Colord-%{gir_major}.typelib
%{_libdir}/girepository-1.0/ColorHug-%{gir_major}.typelib

%files -n %{devname}
%{_includedir}/%{name}-1
%{_libdir}/lib%{name}.so
%{_libdir}/lib%{name}private.so
%{_libdir}/libcolorhug.so
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/pkgconfig/colorhug.pc
%{_datadir}/gir-1.0/Colord-%{gir_major}.gir
%{_datadir}/gir-1.0/ColorHug-%{gir_major}.gir
%{_datadir}/vala/vapi/colord.vapi


%changelog
* Mon Nov 28 2016 luigiwalser <luigiwalser> 1.3.4-1.mga6
+ Revision: 1070580
- 1.3.4

* Thu Aug 11 2016 luigiwalser <luigiwalser> 1.3.3-1.mga6
+ Revision: 1045483
- 1.3.3

* Mon May 09 2016 luigiwalser <luigiwalser> 1.3.2-1.mga6
+ Revision: 1011339
- 1.3.2

* Thu Dec 31 2015 luigiwalser <luigiwalser> 1.3.1-1.mga6
+ Revision: 917380
- 1.3.1

* Wed Nov 04 2015 neoclust <neoclust> 1.2.12-3.mga6
+ Revision: 897738
- Rebuild to make availaable on ARM

* Wed Oct 28 2015 joequant <joequant> 1.2.12-2.mga6
+ Revision: 895990
- remove daemon from library

* Fri Oct 09 2015 ovitters <ovitters> 1.2.12-1.mga6
+ Revision: 888508
- new version 1.2.12

* Sun Jun 28 2015 wally <wally> 1.2.11-2.mga6
+ Revision: 847167
- add requires for gir pkg to devel pkg

* Sun Jun 21 2015 ovitters <ovitters> 1.2.11-1.mga6
+ Revision: 837837
- new version 1.2.11
- dropped merged patch 1

* Thu Nov 20 2014 luigiwalser <luigiwalser> 1.2.4-3.mga5
+ Revision: 797960
- add upstream patch via fedora to fix calibration using helper (rhbz#1157279)

* Wed Oct 15 2014 umeabot <umeabot> 1.2.4-2.mga5
+ Revision: 743127
- Second Mageia 5 Mass Rebuild

* Tue Oct 14 2014 luigiwalser <luigiwalser> 1.2.4-1.mga5
+ Revision: 738647
- 1.2.4

* Wed Oct 08 2014 luigiwalser <luigiwalser> 1.2.3-1.mga5
+ Revision: 737586
- 1.2.3

* Sun Sep 28 2014 tv <tv> 1.2.2-5.mga5
+ Revision: 731115
- rebuild so that it picks typelib() requires

* Thu Sep 18 2014 umeabot <umeabot> 1.2.2-4.mga5
+ Revision: 693660
- Rebuild to fix library dependencies

* Tue Sep 16 2014 umeabot <umeabot> 1.2.2-3.mga5
+ Revision: 678480
- Mageia 5 Mass Rebuild

* Thu Sep 04 2014 colin <colin> 1.2.2-2.mga5
+ Revision: 671859
- Rebuild for new systemd

* Tue Aug 19 2014 luigiwalser <luigiwalser> 1.2.2-1.mga5
+ Revision: 665766
- 1.2.2

* Wed May 28 2014 luigiwalser <luigiwalser> 1.2.1-1.mga5
+ Revision: 627283
- 1.2.1

* Sat Apr 26 2014 luigiwalser <luigiwalser> 1.2.0-1.mga5
+ Revision: 618241
- 1.2.0

* Sun Mar 02 2014 luigiwalser <luigiwalser> 1.1.7-1.mga5
+ Revision: 598487
- 1.1.7

* Tue Feb 11 2014 luigiwalser <luigiwalser> 1.1.6-1.mga5
+ Revision: 589166
- 1.1.6

* Fri Dec 13 2013 luigiwalser <luigiwalser> 1.1.5-1.mga4
+ Revision: 556536
- 1.1.5

* Fri Dec 06 2013 luigiwalser <luigiwalser> 1.1.4-1.mga4
+ Revision: 555716
- 1.1.4

* Sat Oct 19 2013 umeabot <umeabot> 1.1.2-4.mga4
+ Revision: 534783
- Mageia 4 Mass Rebuild

  + neoclust <neoclust>
    - revert previous change

* Sat Sep 14 2013 neoclust <neoclust> 1.1.2-3.mga4
+ Revision: 478843
- libcolord.so.2() is already a require added by rpm, do not hardcode it

* Sat Sep 14 2013 wally <wally> 1.1.2-2.mga4
+ Revision: 478832
- loosen lib pkg requires

* Sat Sep 14 2013 wally <wally> 1.1.2-1.mga4
+ Revision: 478816
- new libmajor 2
- new version 1.1.2

* Wed Jul 10 2013 luigiwalser <luigiwalser> 1.0.2-1.mga4
+ Revision: 452562
- 1.0.2

* Sun Jun 16 2013 wally <wally> 1.0.1-2.mga4
+ Revision: 443582
- fix UTF-8 related build warning

* Sun Jun 16 2013 wally <wally> 1.0.1-1.mga4
+ Revision: 443572
- new version 1.0.1
- sync .spec from Fedora
- obsolete shared-color-profiles and shared-color-profiles-extra (now included in colord)
- run daemon as colord user

* Fri May 31 2013 wally <wally> 1.0.0-1.mga4
+ Revision: 433853
- new version 1.0.0

* Sat May 25 2013 ovitters <ovitters> 0.1.34-1.mga4
+ Revision: 427066
- ensure vala is built
- update file list
- br dbus-1
- enable sane
- br bash-completion
- new version 0.1.34

* Fri Jan 11 2013 umeabot <umeabot> 0.1.23-3.mga3
+ Revision: 348009
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Jan 02 2013 pterjan <pterjan> 0.1.23-2.mga3
+ Revision: 337862
- Fix for _libdir != _libexecdir

* Fri Oct 19 2012 fwang <fwang> 0.1.23-1.mga3
+ Revision: 308163
- drop unused instruction
- new version 0.1.23

* Tue Jul 31 2012 sander85 <sander85> 0.1.22-1.mga3
+ Revision: 276590
- New version: 0.1.22.

* Fri Jun 15 2012 fwang <fwang> 0.1.21-1.mga3
+ Revision: 260725
- update file list
- update file list
- new version 0.1.21

* Sat Apr 28 2012 tmb <tmb> 0.1.17-3.mga2
+ Revision: 233625
- Require rpm-helper >= 0.24.8-1 for systemd support

* Fri Apr 27 2012 tmb <tmb> 0.1.17-2.mga2
+ Revision: 233529
- rebuild for versioned rpm-helper requires

* Fri Mar 02 2012 wally <wally> 0.1.17-1.mga2
+ Revision: 216838
- new version 0.1.17

* Tue Jan 17 2012 wally <wally> 0.1.16-1.mga2
+ Revision: 197403
- new version 0.1.16
- drop patch from upstream
- enable systemd support
- clean .spec a bit

* Tue Dec 13 2011 wally <wally> 0.1.15-4.mga2
+ Revision: 181390
- fix setfacl path on udev rule (mga#3728)

* Tue Dec 06 2011 wally <wally> 0.1.15-3.mga2
+ Revision: 177826
- add patch from uptream git to fix possible rescan issues

* Mon Nov 28 2011 wally <wally> 0.1.15-2.mga2
+ Revision: 173797
- enable gusb support

* Mon Nov 28 2011 wally <wally> 0.1.15-1.mga2
+ Revision: 173768
- new version 0.1.15
- fixes CVE-2011-4349

* Fri Nov 11 2011 wally <wally> 0.1.14-1.mga2
+ Revision: 166743
- new version 0.1.14

* Mon Oct 03 2011 fwang <fwang> 0.1.13-1.mga2
+ Revision: 151287
- new version 0.1.13

* Mon Oct 03 2011 fwang <fwang> 0.1.12-3.mga2
+ Revision: 151245
- add more br
- br polkit
- fix wrong num
- add req
- update file list
- update br of sane
- cleanup br

* Tue Sep 06 2011 fwang <fwang> 0.1.12-2.mga2
+ Revision: 139048
- add req on private requires

* Tue Aug 30 2011 fwang <fwang> 0.1.12-1.mga2
+ Revision: 136565
- new version 0.1.12

  + wally <wally>
    - new version 0.1.11
    - enable introspection

* Tue Jul 12 2011 ahmad <ahmad> 0.1.10-1.mga2
+ Revision: 123115
- Update to 0.1.10

* Mon Jul 11 2011 wally <wally> 0.1.9-2.mga2
+ Revision: 122327
- fix requires

* Tue Jul 05 2011 wally <wally> 0.1.9-1.mga2
+ Revision: 118871
- imported package colord

